==> imageio-ext-nitf-2.0.0-sources.jar: it/geosolutions/imageio/plugins/nitronitf/wrapper/IdentifiableNITFObjectWrapper.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2012, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.nitronitf.wrapper;

/**
 * Wrapper class for an identifiable NITF object. Main identification fields are Id, title and
 * dateTime.
 * 
 * @author Daniele Romagnoli, GeoSolutions s.a.s.
 */
public class IdentifiableNITFObjectWrapper extends NITFObjectWrapper {

    public IdentifiableNITFObjectWrapper() {
        super();
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getDateTime() {
        return dateTime;
    }

    public void setDateTime(String dateTime) {
        this.dateTime = dateTime;
    }

    private String title;

    private String id;

    private String dateTime;

}

==> imageio-ext-nitf-2.1-20251124.135906-5-sources.jar: it/geosolutions/imageio/plugins/nitronitf/wrapper/IdentifiableNITFObjectWrapper.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2012, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.nitronitf.wrapper;

/**
 * Wrapper class for an identifiable NITF object. Main identification fields are Id, title and dateTime.
 *
 * @author Daniele Romagnoli, GeoSolutions s.a.s.
 */
public class IdentifiableNITFObjectWrapper extends NITFObjectWrapper {

    public IdentifiableNITFObjectWrapper() {
        super();
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getDateTime() {
        return dateTime;
    }

    public void setDateTime(String dateTime) {
        this.dateTime = dateTime;
    }

    private String title;

    private String id;

    private String dateTime;
}
